@@ -10,7 +10,7 @@
 #define KASTEN_TERMINALTOOLVIEWFACTORY_HPP
 
 // lib
-#include <kasten/kastencontrollers_export.hpp>
+#include "kastencontrollers_export.hpp"
 // Kasten gui
 #include <Kasten/AbstractToolViewFactory>
 
@@ -20,8 +20,12 @@ class KASTENCONTROLLERS_EXPORT TerminalToolViewFactory : public AbstractToolView
 {
 public:
     TerminalToolViewFactory();
+    TerminalToolViewFactory(const TerminalToolViewFactory&) = delete;
+
     ~TerminalToolViewFactory() override;
 
+    TerminalToolViewFactory& operator=(const TerminalToolViewFactory&) = delete;
+
 public: // AbstractToolViewFactory API
     AbstractToolView* create(AbstractTool* tool) const override;
 
