@@ -10,7 +10,7 @@
 #define KASTEN_CHARSETCONVERSIONTOOLVIEWFACTORY_HPP
 
 // lib
-#include <kasten/okteta/oktetakastencontrollers_export.hpp>
+#include "oktetakastencontrollers_export.hpp"
 // Kasten gui
 #include <Kasten/AbstractToolViewFactory>
 
@@ -20,8 +20,12 @@ class OKTETAKASTENCONTROLLERS_EXPORT CharsetConversionToolViewFactory : public A
 {
 public:
     CharsetConversionToolViewFactory();
+    CharsetConversionToolViewFactory(const CharsetConversionToolViewFactory&) = delete;
+
     ~CharsetConversionToolViewFactory() override;
 
+    CharsetConversionToolViewFactory& operator=(const CharsetConversionToolViewFactory&) = delete;
+
 public: // AbstractToolViewFactory API
     AbstractToolView* create(AbstractTool* tool) const override;
 
