@@ -10,7 +10,7 @@
 #define KASTEN_OVERWRITEMODECONTROLLERFACTORY_HPP
 
 // lib
-#include <kasten/okteta/oktetakastencontrollers_export.hpp>
+#include "oktetakastencontrollers_export.hpp"
 // Kasten core
 #include <Kasten/AbstractXmlGuiControllerFactory>
 
@@ -20,8 +20,12 @@ class OKTETAKASTENCONTROLLERS_EXPORT OverwriteModeControllerFactory : public Abs
 {
 public:
     OverwriteModeControllerFactory();
+    OverwriteModeControllerFactory(const OverwriteModeControllerFactory&) = delete;
+
     ~OverwriteModeControllerFactory() override;
 
+    OverwriteModeControllerFactory& operator=(const OverwriteModeControllerFactory&) = delete;
+
 public: // AbstractXmlGuiControllerFactory API
     AbstractXmlGuiController* create(KXMLGUIClient* guiClient) const override;
 };
